/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.uuid;

import org.junit.Assert;
import org.junit.Test;

import com.ebmwebsourcing.easycommons.uuid.framework.orchestrator.GenUUIDFromSingleSimpleGeneratorOrchestrator;

public class SimpleUUIDGeneratorTest {

    /**
     * Number of simultaneously launched uuid generator thread
     */
    private final int POOL_SIZE = 100;

    /**
     * Number of uuids generated by each thread
     */
    private final int ITERATIONS = 100;

    @Test
    public void testGetNewIDMethodIsThreadsafe() {
        try {
            System.gc();
            new GenUUIDFromSingleSimpleGeneratorOrchestrator().orchestrate(POOL_SIZE, ITERATIONS);
        } catch (Exception e) {
            Assert.fail(e.getMessage());
        }
    }

    @Test
    public void testGetNewID() {
        SimpleUUIDGenerator generator = new SimpleUUIDGenerator();
        String uuidPatern = "^[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}$";
        String uuid = generator.getNewID();
        Assert.assertTrue("Generated uuid must match the followwing pattern "
                + "'[a-f0-9]{8}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{4}-[a-f0-9]{12}'",
                uuid.matches(uuidPatern));
    }

}
