/**
 * Copyright (c) 2010-2012 EBM WebSourcing, 2012-2018 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the New BSD License (3-clause license).
 *
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the New BSD License (3-clause license)
 * for more details.
 *
 * You should have received a copy of the New BSD License (3-clause license)
 * along with this program/library; If not, see http://directory.fsf.org/wiki/License:BSD_3Clause/
 * for the New BSD License (3-clause license).
 */
package com.ebmwebsourcing.easycommons.uuid.framework.generator;

import java.util.Set;

import org.junit.Assert;

public abstract class AbstractGeneratorTask implements Runnable {

    private final int nbIterates;

    private final Set<String> uuids;

    public AbstractGeneratorTask(final int nbIterates,
            final Set<String> uuids) {
        this.nbIterates = nbIterates;
        this.uuids = uuids;
    }

    public void run() {
        for (int i = 0; i < this.nbIterates; i++) {
            final String uid = this.getUID();
            synchronized (this.uuids) {
                if (uuids.contains(uid)) {
                    Assert.fail("Non unique id generated");
                } else {
                    uuids.add(uid);
                }
            }
        }
    }

    protected abstract String getUID();
}
